@@ -27,7 +27,13 @@ from .exception import (
     RestrictedBucketMissing,
 )
 from .file_lock import FileRetentionSetting, LegalHold
-from .file_version import DownloadVersionFactory, FileIdAndName, FileVersion, FileVersionFactory
+from .file_version import (
+    DownloadVersion,
+    DownloadVersionFactory,
+    FileIdAndName,
+    FileVersion,
+    FileVersionFactory,
+)
 from .large_file.services import LargeFileServices
 from .progress import AbstractProgressListener
 from .raw_api import API_VERSION, LifecycleRule
@@ -65,6 +71,7 @@ class Services:
     UPLOAD_MANAGER_CLASS = staticmethod(UploadManager)
     COPY_MANAGER_CLASS = staticmethod(CopyManager)
     DOWNLOAD_MANAGER_CLASS = staticmethod(DownloadManager)
+    LARGE_FILE_SERVICES_CLASS = staticmethod(LargeFileServices)
 
     def __init__(
         self,
@@ -89,7 +96,7 @@ class Services:
         """
         self.api = api
         self.session = api.session
-        self.large_file = LargeFileServices(self)
+        self.large_file = self.LARGE_FILE_SERVICES_CLASS(self)
         self.upload_manager = self.UPLOAD_MANAGER_CLASS(
             services=self, max_workers=max_upload_workers
         )
@@ -454,12 +461,15 @@ class B2Api(metaclass=B2TraceMeta):
         """
         return self.services.large_file.cancel_large_file(file_id)
 
-    def delete_file_version(self, file_id: str, file_name: str) -> FileIdAndName:
+    def delete_file_version(
+        self, file_id: str, file_name: str, bypass_governance: bool = False
+    ) -> FileIdAndName:
         """
-        Permanently and irrevocably delete one version of a file.
+        Permanently and irrevocably delete one version of a file. bypass_governance must be set to true if deleting a
+        file version protected by Object Lock governance mode retention settings (unless its retention period expired)
         """
         # filename argument is not first, because one day it may become optional
-        response = self.session.delete_file_version(file_id, file_name)
+        response = self.session.delete_file_version(file_id, file_name, bypass_governance)
         return FileIdAndName.from_cancel_or_delete_response(response)
 
     # download
@@ -587,6 +597,17 @@ class B2Api(metaclass=B2TraceMeta):
             self.session.get_file_info_by_id(file_id)
         )
 
+    def get_file_info_by_name(self, bucket_name: str, file_name: str) -> DownloadVersion:
+        """
+        Gets info about a file version. Similar to `get_file_info` but 
+        takes the bucket name and file name instead of file id.
+
+        :param str bucket_name: The name of the bucket where the file resides.
+        :param str file_name: The name of the file whose info will be retrieved.
+        """
+        bucket = self.get_bucket_by_name(bucket_name)
+        return bucket.get_file_info_by_name(file_name)
+
     def check_bucket_name_restrictions(self, bucket_name: str):
         """
         Check to see if the allowed field from authorize-account has a bucket restriction.
