@@ -7,9 +7,8 @@
 # License https://www.backblaze.com/using_b2_code.html
 #
 ######################################################################
+from __future__ import annotations
 
-from random import random
-from contextlib import contextmanager
 import datetime
 import io
 import json
@@ -17,19 +16,30 @@ import locale
 import logging
 import socket
 import threading
+import time
+from contextlib import contextmanager
+from random import random
+from typing import Any
 
 import requests
 from requests.adapters import HTTPAdapter
-import time
-
-from typing import Any, Dict, Optional
 
+from .api_config import DEFAULT_HTTP_API_CONFIG, B2HttpApiConfig
 from .exception import (
-    B2Error, B2RequestTimeoutDuringUpload, BadDateFormat, BrokenPipe, B2ConnectionError,
-    B2RequestTimeout, ClockSkew, ConnectionReset, interpret_b2_error, UnknownError, UnknownHost,
-    InvalidJsonResponse, PotentialS3EndpointPassedAsRealm
+    B2ConnectionError,
+    B2Error,
+    B2RequestTimeout,
+    B2RequestTimeoutDuringUpload,
+    BadDateFormat,
+    BrokenPipe,
+    ClockSkew,
+    ConnectionReset,
+    InvalidJsonResponse,
+    PotentialS3EndpointPassedAsRealm,
+    UnknownError,
+    UnknownHost,
+    interpret_b2_error,
 )
-from .api_config import B2HttpApiConfig, DEFAULT_HTTP_API_CONFIG
 from .requests import NotDecompressingResponse
 from .version import USER_AGENT
 
@@ -213,7 +223,7 @@ class B2Http:
         data,
         try_count: int = TRY_COUNT_DATA,
         post_params=None,
-        _timeout: Optional[int] = None,
+        _timeout: int | None = None,
     ):
         """
         Use like this:
@@ -343,9 +353,9 @@ class B2Http:
     def head_content(
         self,
         url: str,
-        headers: Dict[str, Any],
+        headers: dict[str, Any],
         try_count: int = TRY_COUNT_HEAD,
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         """
         Does a HEAD instead of a GET for the URL.
         The response's content is limited to the headers.
@@ -388,7 +398,7 @@ class B2Http:
     @classmethod
     def _get_user_agent(cls, user_agent_append):
         if user_agent_append:
-            return '%s %s' % (USER_AGENT, user_agent_append)
+            return f'{USER_AGENT} {user_agent_append}'
         return USER_AGENT
 
     def _run_pre_request_hooks(self, method, url, headers):
