@@ -9,6 +9,7 @@
 ######################################################################
 from __future__ import annotations
 
+import datetime as dt
 import fnmatch
 import logging
 import pathlib
@@ -32,6 +33,7 @@ from .file_lock import (
     LegalHold,
 )
 from .file_version import DownloadVersion, FileVersion
+from .http_constants import LIST_FILE_NAMES_MAX_LIMIT
 from .progress import AbstractProgressListener, DoNothingProgressListener
 from .raw_api import LifecycleRule
 from .replication.setting import ReplicationConfiguration, ReplicationConfigurationFactory
@@ -110,6 +112,41 @@ class Bucket(metaclass=B2TraceMeta):
         self.is_file_lock_enabled = is_file_lock_enabled
         self.replication = replication
 
+    def _add_file_info_item(self, file_info: dict[str, str], name: str, value: str | None):
+        if value is not None:
+            if name in file_info and file_info[name] != value:
+                logger.warning(
+                    'Overwriting file info key %s with value %s (previous value %s)', name, value,
+                    file_info[name]
+                )
+            file_info[name] = value
+
+    def _merge_file_info_and_headers_params(
+        self,
+        file_info: dict | None,
+        cache_control: str | None,
+        expires: str | dt.datetime | None,
+        content_disposition: str | None,
+        content_encoding: str | None,
+        content_language: str | None,
+    ) -> dict | None:
+        updated_file_info = {**(file_info or {})}
+
+        if isinstance(expires, dt.datetime):
+            expires = expires.astimezone(dt.timezone.utc)
+            expires = dt.datetime.strftime(expires, '%a, %d %b %Y %H:%M:%S GMT')
+
+        self._add_file_info_item(updated_file_info, 'b2-expires', expires)
+        self._add_file_info_item(updated_file_info, 'b2-cache-control', cache_control)
+        self._add_file_info_item(updated_file_info, 'b2-content-disposition', content_disposition)
+        self._add_file_info_item(updated_file_info, 'b2-content-encoding', content_encoding)
+        self._add_file_info_item(updated_file_info, 'b2-content-language', content_language)
+
+        # If file_info was None and we didn't add anything, we want to return None
+        if not updated_file_info:
+            return file_info
+        return updated_file_info
+
     def get_fresh_state(self) -> Bucket:
         """
         Fetch all the information about this bucket and return a new bucket object.
@@ -293,12 +330,14 @@ class Bucket(metaclass=B2TraceMeta):
         """
         return self.api.list_parts(file_id, start_part_number, batch_size)
 
-    def list_file_versions(self, file_name, fetch_count=None):
+    def list_file_versions(
+        self, file_name: str, fetch_count: int | None = LIST_FILE_NAMES_MAX_LIMIT
+    ):
         """
         Lists all of the versions for a single file.
 
-        :param str file_name: the name of the file to list.
-        :param int,None fetch_count: how many entries to list per API call or ``None`` to use the default. Acceptable values: 1 - 10000
+        :param file_name: the name of the file to list.
+        :param fetch_count: how many entries to list per API call or ``None`` to use the default. Acceptable values: 1 - 10000
         :rtype: generator[b2sdk.v2.FileVersion]
         """
         if fetch_count is not None and fetch_count <= 0:
@@ -328,7 +367,7 @@ class Bucket(metaclass=B2TraceMeta):
         folder_to_list: str = '',
         latest_only: bool = True,
         recursive: bool = False,
-        fetch_count: int | None = 10000,
+        fetch_count: int | None = LIST_FILE_NAMES_MAX_LIMIT,
         with_wildcard: bool = False,
     ):
         """
@@ -347,7 +386,7 @@ class Bucket(metaclass=B2TraceMeta):
         :param latest_only: when ``False`` returns info about all versions of a file,
                             when ``True``, just returns info about the most recent versions
         :param recursive: if ``True``, list folders recursively
-        :param fetch_count: how many entries to return or ``None`` to use the default. Acceptable values: 1 - 10000
+        :param fetch_count: how many entries to list per API call or ``None`` to use the default. Acceptable values: 1 - 10000
         :param with_wildcard: Accepts "*", "?", "[]" and "[!]" in folder_to_list, similarly to what shell does.
                               As of 1.19.0 it can only be enabled when recursive is also enabled.
                               Also, in this mode, folder_to_list is considered to be a filename or a pattern.
@@ -496,6 +535,10 @@ class Bucket(metaclass=B2TraceMeta):
         large_file_sha1: Sha1HexDigest | None = None,
         custom_upload_timestamp: int | None = None,
         cache_control: str | None = None,
+        expires: str | dt.datetime | None = None,
+        content_disposition: str | None = None,
+        content_encoding: str | None = None,
+        content_language: str | None = None,
     ):
         """
         Upload bytes in memory to a B2 file.
@@ -513,7 +556,18 @@ class Bucket(metaclass=B2TraceMeta):
         :param bool legal_hold: legal hold setting
         :param Sha1HexDigest,None large_file_sha1: SHA-1 hash of the result file or ``None`` if unknown
         :param int,None custom_upload_timestamp: override object creation date, expressed as a number of milliseconds since epoch
-        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616. Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616.
+            Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,datetime.datetime,None expires: an optional cache expiration setting.
+            If this argument is a string, its syntax must be based on the section 14.21 of RFC 2616.
+            Example string value: 'Thu, 01 Dec 2050 16:00:00 GMT'. If this argument is a datetime,
+            it will be converted to a string in the same format.
+        :param str,None content_disposition: an optional content disposition setting. Syntax based on the section 19.5.1 of RFC 2616.
+            Example string value: 'attachment; filename="fname.ext"'.
+        :param str,None content_encoding: an optional content encoding setting.Syntax based on the section 14.11 of RFC 2616.
+            Example string value: 'gzip'.
+        :param str,None content_language: an optional content language setting. Syntax based on the section 14.12 of RFC 2616.
+            Example string value: 'mi, en_US'.
         :rtype: b2sdk.v2.FileVersion
         """
         upload_source = UploadSourceBytes(data_bytes)
@@ -529,6 +583,10 @@ class Bucket(metaclass=B2TraceMeta):
             large_file_sha1=large_file_sha1,
             custom_upload_timestamp=custom_upload_timestamp,
             cache_control=cache_control,
+            expires=expires,
+            content_disposition=content_disposition,
+            content_encoding=content_encoding,
+            content_language=content_language,
         )
 
     def upload_local_file(
@@ -546,6 +604,10 @@ class Bucket(metaclass=B2TraceMeta):
         upload_mode: UploadMode = UploadMode.FULL,
         custom_upload_timestamp: int | None = None,
         cache_control: str | None = None,
+        expires: str | dt.datetime | None = None,
+        content_disposition: str | None = None,
+        content_encoding: str | None = None,
+        content_language: str | None = None,
     ):
         """
         Upload a file on local disk to a B2 file.
@@ -569,7 +631,18 @@ class Bucket(metaclass=B2TraceMeta):
         :param bool legal_hold: legal hold setting
         :param b2sdk.v2.UploadMode upload_mode: desired upload mode
         :param int,None custom_upload_timestamp: override object creation date, expressed as a number of milliseconds since epoch
-        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616. Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616.
+            Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,datetime.datetime,None expires: an optional cache expiration setting.
+            If this argument is a string, its syntax must be based on the section 14.21 of RFC 2616.
+            Example string value: 'Thu, 01 Dec 2050 16:00:00 GMT'. If this argument is a datetime,
+            it will be converted to a string in the same format.
+        :param str,None content_disposition: an optional content disposition setting. Syntax based on the section 19.5.1 of RFC 2616.
+            Example string value: 'attachment; filename="fname.ext"'.
+        :param str,None content_encoding: an optional content encoding setting.Syntax based on the section 14.11 of RFC 2616.
+            Example string value: 'gzip'.
+        :param str,None content_language: an optional content language setting. Syntax based on the section 14.12 of RFC 2616.
+            Example string value: 'mi, en_US'.
         :rtype: b2sdk.v2.FileVersion
         """
         upload_source = UploadSourceLocalFile(local_path=local_file, content_sha1=sha1_sum)
@@ -589,6 +662,14 @@ class Bucket(metaclass=B2TraceMeta):
                     # the upload will be incremental, but the SHA1 sum is unknown, calculate it now
                     large_file_sha1 = upload_source.get_content_sha1()
 
+        file_info = self._merge_file_info_and_headers_params(
+            file_info=file_info,
+            cache_control=cache_control,
+            expires=expires,
+            content_disposition=content_disposition,
+            content_encoding=content_encoding,
+            content_language=content_language,
+        )
         return self.concatenate(
             sources,
             file_name,
@@ -601,7 +682,6 @@ class Bucket(metaclass=B2TraceMeta):
             legal_hold=legal_hold,
             large_file_sha1=large_file_sha1,
             custom_upload_timestamp=custom_upload_timestamp,
-            cache_control=cache_control,
         )
 
     def upload_unbound_stream(
@@ -624,6 +704,10 @@ class Bucket(metaclass=B2TraceMeta):
         unused_buffer_timeout_seconds: float = 3600.0,
         custom_upload_timestamp: int | None = None,
         cache_control: str | None = None,
+        expires: str | dt.datetime | None = None,
+        content_disposition: str | None = None,
+        content_encoding: str | None = None,
+        content_language: str | None = None,
     ):
         """
         Upload an unbound file-like read-only object to a B2 file.
@@ -649,20 +733,22 @@ class Bucket(metaclass=B2TraceMeta):
         ``min_part_size``, ``recommended_upload_part_size`` and ``max_part_size`` should
         all be greater than ``account_info.get_absolute_minimum_part_size()``.
 
-        ``buffers_count`` describes a desired number of buffers that are to be used. Minimal amount is two, as we need
+        ``buffers_count`` describes a desired number of buffers that are to be used.
+        Minimal amount is 2.
         to determine the method of uploading this stream (if there's only a single buffer we send it as a normal file,
         if there are at least two – as a large file).
-        Number of buffers determines the amount of memory used by the streaming process and, in turns, describe
-        the amount of data that can be pulled from ``read_only_object`` while also uploading it. Providing multiple
-        buffers also allows for higher parallelization. Default two buffers allow for the process to fill one buffer
-        with data while the other one is being sent to the B2. While only one buffer can be filled with data at once,
+        Number of buffers determines the amount of memory used by the streaming process and
+        the amount of data that can be pulled from ``read_only_object`` while also uploading it.
+        Providing more buffers allows for higher upload parallelization.
+        While only one buffer can be filled with data at once,
         all others are used to send the data in parallel (limited only by the number of parallel threads).
-        Buffer size can be controlled by ``buffer_size`` parameter. If left unset, it will default to
-        a value of ``recommended_upload_part_size``, whatever it resolves to be.
+
+        Buffer size can be controlled by ``buffer_size`` parameter.
+        If left unset, it will default to a value of ``recommended_upload_part_size``.
         Note that in the current implementation buffers are (almost) directly sent to B2, thus whatever is picked
         as the ``buffer_size`` will also become the size of the part when uploading a large file in this manner.
         In rare cases, namely when the whole buffer was sent, but there was an error during sending of last bytes
-        and a retry was issued, another buffer (above the aforementioned limit) will be allocated.
+        and a retry was issued, additional buffer (above the aforementioned limit) will be temporarily allocated.
 
         .. note:
             ``custom_upload_timestamp`` is disabled by default - please talk to customer support to enable it on your account (if you really need it)
@@ -687,7 +773,18 @@ class Bucket(metaclass=B2TraceMeta):
         :param read_size: size of a single read operation performed on the ``read_only_object``
         :param unused_buffer_timeout_seconds: amount of time that a buffer can be idle before returning error
         :param int,None custom_upload_timestamp: override object creation date, expressed as a number of milliseconds since epoch
-        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616. Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616.
+            Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,datetime.datetime,None expires: an optional cache expiration setting.
+            If this argument is a string, its syntax must be based on the section 14.21 of RFC 2616.
+            Example string value: 'Thu, 01 Dec 2050 16:00:00 GMT'. If this argument is a datetime,
+            it will be converted to a string in the same format.
+        :param str,None content_disposition: an optional content disposition setting. Syntax based on the section 19.5.1 of RFC 2616.
+            Example string value: 'attachment; filename="fname.ext"'.
+        :param str,None content_encoding: an optional content encoding setting.Syntax based on the section 14.11 of RFC 2616.
+            Example string value: 'gzip'.
+        :param str,None content_language: an optional content language setting. Syntax based on the section 14.12 of RFC 2616.
+            Example string value: 'mi, en_US'.
         :rtype: b2sdk.v2.FileVersion
         """
         if buffers_count <= 1:
@@ -702,6 +799,14 @@ class Bucket(metaclass=B2TraceMeta):
             planner = self.api.services.emerger.get_emerge_planner()
             buffer_size = planner.recommended_upload_part_size
 
+        file_info = self._merge_file_info_and_headers_params(
+            file_info=file_info,
+            cache_control=cache_control,
+            expires=expires,
+            content_disposition=content_disposition,
+            content_encoding=content_encoding,
+            content_language=content_language,
+        )
         return self._create_file(
             self.api.services.emerger.emerge_unbound,
             UnboundWriteIntentGenerator(
@@ -727,7 +832,6 @@ class Bucket(metaclass=B2TraceMeta):
             max_queue_size=buffers_count - 1,
             large_file_sha1=large_file_sha1,
             custom_upload_timestamp=custom_upload_timestamp,
-            cache_control=cache_control,
         )
 
     def upload(
@@ -744,6 +848,10 @@ class Bucket(metaclass=B2TraceMeta):
         large_file_sha1: Sha1HexDigest | None = None,
         custom_upload_timestamp: int | None = None,
         cache_control: str | None = None,
+        expires: str | dt.datetime | None = None,
+        content_disposition: str | None = None,
+        content_encoding: str | None = None,
+        content_language: str | None = None,
     ):
         """
         Upload a file to B2, retrying as needed.
@@ -770,7 +878,18 @@ class Bucket(metaclass=B2TraceMeta):
         :param bool legal_hold: legal hold setting
         :param Sha1HexDigest,None large_file_sha1: SHA-1 hash of the result file or ``None`` if unknown
         :param int,None custom_upload_timestamp: override object creation date, expressed as a number of milliseconds since epoch
-        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616. Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616.
+            Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,datetime.datetime,None expires: an optional cache expiration setting.
+            If this argument is a string, its syntax must be based on the section 14.21 of RFC 2616.
+            Example string value: 'Thu, 01 Dec 2050 16:00:00 GMT'. If this argument is a datetime,
+            it will be converted to a string in the same format.
+        :param str,None content_disposition: an optional content disposition setting. Syntax based on the section 19.5.1 of RFC 2616.
+            Example string value: 'attachment; filename="fname.ext"'.
+        :param str,None content_encoding: an optional content encoding setting.Syntax based on the section 14.11 of RFC 2616.
+            Example string value: 'gzip'.
+        :param str,None content_language: an optional content language setting. Syntax based on the section 14.12 of RFC 2616.
+            Example string value: 'mi, en_US'.
         :rtype: b2sdk.v2.FileVersion
         """
         return self.create_file(
@@ -787,6 +906,10 @@ class Bucket(metaclass=B2TraceMeta):
             large_file_sha1=large_file_sha1,
             custom_upload_timestamp=custom_upload_timestamp,
             cache_control=cache_control,
+            expires=expires,
+            content_disposition=content_disposition,
+            content_encoding=content_encoding,
+            content_language=content_language,
         )
 
     def create_file(
@@ -806,6 +929,10 @@ class Bucket(metaclass=B2TraceMeta):
         large_file_sha1=None,
         custom_upload_timestamp: int | None = None,
         cache_control: str | None = None,
+        expires: str | dt.datetime | None = None,
+        content_disposition: str | None = None,
+        content_encoding: str | None = None,
+        content_language: str | None = None,
     ):
         """
         Creates a new file in this bucket using an iterable (list, tuple etc) of remote or local sources.
@@ -837,7 +964,18 @@ class Bucket(metaclass=B2TraceMeta):
         :param int max_part_size: upper limit of part size for the transfer planner, in bytes
         :param Sha1HexDigest,None large_file_sha1: SHA-1 hash of the result file or ``None`` if unknown
         :param int,None custom_upload_timestamp: override object creation date, expressed as a number of milliseconds since epoch
-        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616. Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616.
+            Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,datetime.datetime,None expires: an optional cache expiration setting.
+            If this argument is a string, its syntax must be based on the section 14.21 of RFC 2616.
+            Example string value: 'Thu, 01 Dec 2050 16:00:00 GMT'. If this argument is a datetime,
+            it will be converted to a string in the same format.
+        :param str,None content_disposition: an optional content disposition setting. Syntax based on the section 19.5.1 of RFC 2616.
+            Example string value: 'attachment; filename="fname.ext"'.
+        :param str,None content_encoding: an optional content encoding setting.Syntax based on the section 14.11 of RFC 2616.
+            Example string value: 'gzip'.
+        :param str,None content_language: an optional content language setting. Syntax based on the section 14.12 of RFC 2616.
+            Example string value: 'mi, en_US'.
         """
         return self._create_file(
             self.api.services.emerger.emerge,
@@ -856,6 +994,10 @@ class Bucket(metaclass=B2TraceMeta):
             large_file_sha1=large_file_sha1,
             custom_upload_timestamp=custom_upload_timestamp,
             cache_control=cache_control,
+            expires=expires,
+            content_disposition=content_disposition,
+            content_encoding=content_encoding,
+            content_language=content_language,
         )
 
     def create_file_stream(
@@ -875,6 +1017,10 @@ class Bucket(metaclass=B2TraceMeta):
         large_file_sha1=None,
         custom_upload_timestamp: int | None = None,
         cache_control: str | None = None,
+        expires: str | dt.datetime | None = None,
+        content_disposition: str | None = None,
+        content_encoding: str | None = None,
+        content_language: str | None = None,
     ):
         """
         Creates a new file in this bucket using a stream of multiple remote or local sources.
@@ -908,7 +1054,18 @@ class Bucket(metaclass=B2TraceMeta):
         :param int max_part_size: upper limit of part size for the transfer planner, in bytes
         :param Sha1HexDigest,None large_file_sha1: SHA-1 hash of the result file or ``None`` if unknown
         :param int,None custom_upload_timestamp: override object creation date, expressed as a number of milliseconds since epoch
-        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616. Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616.
+            Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,datetime.datetime,None expires: an optional cache expiration setting.
+            If this argument is a string, its syntax must be based on the section 14.21 of RFC 2616.
+            Example string value: 'Thu, 01 Dec 2050 16:00:00 GMT'. If this argument is a datetime,
+            it will be converted to a string in the same format.
+        :param str,None content_disposition: an optional content disposition setting. Syntax based on the section 19.5.1 of RFC 2616.
+            Example string value: 'attachment; filename="fname.ext"'.
+        :param str,None content_encoding: an optional content encoding setting.Syntax based on the section 14.11 of RFC 2616.
+            Example string value: 'gzip'.
+        :param str,None content_language: an optional content language setting. Syntax based on the section 14.12 of RFC 2616.
+            Example string value: 'mi, en_US'.
         """
         return self._create_file(
             self.api.services.emerger.emerge_stream,
@@ -927,6 +1084,10 @@ class Bucket(metaclass=B2TraceMeta):
             large_file_sha1=large_file_sha1,
             custom_upload_timestamp=custom_upload_timestamp,
             cache_control=cache_control,
+            expires=expires,
+            content_disposition=content_disposition,
+            content_encoding=content_encoding,
+            content_language=content_language,
         )
 
     def _create_file(
@@ -945,11 +1106,24 @@ class Bucket(metaclass=B2TraceMeta):
         min_part_size=None,
         max_part_size=None,
         large_file_sha1=None,
+        cache_control: str | None = None,
+        expires: str | dt.datetime | None = None,
+        content_disposition: str | None = None,
+        content_encoding: str | None = None,
+        content_language: str | None = None,
         **kwargs
     ):
         validate_b2_file_name(file_name)
         progress_listener = progress_listener or DoNothingProgressListener()
 
+        file_info = self._merge_file_info_and_headers_params(
+            file_info=file_info,
+            cache_control=cache_control,
+            expires=expires,
+            content_disposition=content_disposition,
+            content_encoding=content_encoding,
+            content_language=content_language,
+        )
         return emerger_method(
             self.id_,
             write_intents_iterable,
@@ -985,6 +1159,10 @@ class Bucket(metaclass=B2TraceMeta):
         large_file_sha1=None,
         custom_upload_timestamp: int | None = None,
         cache_control: str | None = None,
+        expires: str | dt.datetime | None = None,
+        content_disposition: str | None = None,
+        content_encoding: str | None = None,
+        content_language: str | None = None,
     ):
         """
         Creates a new file in this bucket by concatenating multiple remote or local sources.
@@ -1013,7 +1191,18 @@ class Bucket(metaclass=B2TraceMeta):
         :param int max_part_size: upper limit of part size for the transfer planner, in bytes
         :param Sha1HexDigest,None large_file_sha1: SHA-1 hash of the result file or ``None`` if unknown
         :param int,None custom_upload_timestamp: override object creation date, expressed as a number of milliseconds since epoch
-        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616. Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616.
+            Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,datetime.datetime,None expires: an optional cache expiration setting.
+            If this argument is a string, its syntax must be based on the section 14.21 of RFC 2616.
+            Example string value: 'Thu, 01 Dec 2050 16:00:00 GMT'. If this argument is a datetime,
+            it will be converted to a string in the same format.
+        :param str,None content_disposition: an optional content disposition setting. Syntax based on the section 19.5.1 of RFC 2616.
+            Example string value: 'attachment; filename="fname.ext"'.
+        :param str,None content_encoding: an optional content encoding setting.Syntax based on the section 14.11 of RFC 2616.
+            Example string value: 'gzip'.
+        :param str,None content_language: an optional content language setting. Syntax based on the section 14.12 of RFC 2616.
+            Example string value: 'mi, en_US'.
         """
         return self.create_file(
             list(WriteIntent.wrap_sources_iterator(outbound_sources)),
@@ -1031,6 +1220,10 @@ class Bucket(metaclass=B2TraceMeta):
             large_file_sha1=large_file_sha1,
             custom_upload_timestamp=custom_upload_timestamp,
             cache_control=cache_control,
+            expires=expires,
+            content_disposition=content_disposition,
+            content_encoding=content_encoding,
+            content_language=content_language,
         )
 
     def concatenate_stream(
@@ -1048,6 +1241,10 @@ class Bucket(metaclass=B2TraceMeta):
         large_file_sha1: Sha1HexDigest | None = None,
         custom_upload_timestamp: int | None = None,
         cache_control: str | None = None,
+        expires: str | dt.datetime | None = None,
+        content_disposition: str | None = None,
+        content_encoding: str | None = None,
+        content_language: str | None = None,
     ):
         """
         Creates a new file in this bucket by concatenating stream of multiple remote or local sources.
@@ -1072,7 +1269,18 @@ class Bucket(metaclass=B2TraceMeta):
         :param bool legal_hold: legal hold setting
         :param Sha1HexDigest,None large_file_sha1: SHA-1 hash of the result file or ``None`` if unknown
         :param int,None custom_upload_timestamp: override object creation date, expressed as a number of milliseconds since epoch
-        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616. Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616.
+            Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,datetime.datetime,None expires: an optional cache expiration setting.
+            If this argument is a string, its syntax must be based on the section 14.21 of RFC 2616.
+            Example string value: 'Thu, 01 Dec 2050 16:00:00 GMT'. If this argument is a datetime,
+            it will be converted to a string in the same format.
+        :param str,None content_disposition: an optional content disposition setting. Syntax based on the section 19.5.1 of RFC 2616.
+            Example string value: 'attachment; filename="fname.ext"'.
+        :param str,None content_encoding: an optional content encoding setting.Syntax based on the section 14.11 of RFC 2616.
+            Example string value: 'gzip'.
+        :param str,None content_language: an optional content language setting. Syntax based on the section 14.12 of RFC 2616.
+            Example string value: 'mi, en_US'.
         """
         return self.create_file_stream(
             WriteIntent.wrap_sources_iterator(outbound_sources_iterator),
@@ -1088,6 +1296,10 @@ class Bucket(metaclass=B2TraceMeta):
             large_file_sha1=large_file_sha1,
             custom_upload_timestamp=custom_upload_timestamp,
             cache_control=cache_control,
+            expires=expires,
+            content_disposition=content_disposition,
+            content_encoding=content_encoding,
+            content_language=content_language,
         )
 
     def get_download_url(self, filename):
@@ -1131,6 +1343,10 @@ class Bucket(metaclass=B2TraceMeta):
         cache_control: str | None = None,
         min_part_size=None,
         max_part_size=None,
+        expires: str | dt.datetime | None = None,
+        content_disposition: str | None = None,
+        content_encoding: str | None = None,
+        content_language: str | None = None,
     ):
         """
         Creates a new file in this bucket by (server-side) copying from an existing file.
@@ -1156,9 +1372,18 @@ class Bucket(metaclass=B2TraceMeta):
         :param str,None source_content_type: source file's content type, useful when copying files with SSE-C
         :param b2sdk.v2.FileRetentionSetting file_retention: file retention setting for the new file.
         :param bool legal_hold: legal hold setting for the new file.
-        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616. Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
-        :param int min_part_size: lower limit of part size for the transfer planner, in bytes
-        :param int max_part_size: upper limit of part size for the transfer planner, in bytes
+        :param str,None cache_control: an optional cache control setting. Syntax based on the section 14.9 of RFC 2616.
+            Example string value: 'public, max-age=86400, s-maxage=3600, no-transform'.
+        :param str,datetime.datetime,None expires: an optional cache expiration setting.
+            If this argument is a string, its syntax must be based on the section 14.21 of RFC 2616.
+            Example string value: 'Thu, 01 Dec 2050 16:00:00 GMT'. If this argument is a datetime,
+            it will be converted to a string in the same format.
+        :param str,None content_disposition: an optional content disposition setting. Syntax based on the section 19.5.1 of RFC 2616.
+            Example string value: 'attachment; filename="fname.ext"'.
+        :param str,None content_encoding: an optional content encoding setting.Syntax based on the section 14.11 of RFC 2616.
+            Example string value: 'gzip'.
+        :param str,None content_language: an optional content language setting. Syntax based on the section 14.12 of RFC 2616.
+            Example string value: 'mi, en_US'.
         """
 
         copy_source = CopySource(
@@ -1174,6 +1399,14 @@ class Bucket(metaclass=B2TraceMeta):
             validate_b2_file_name(new_file_name)
             try:
                 progress_listener = progress_listener or DoNothingProgressListener()
+                file_info = self._merge_file_info_and_headers_params(
+                    file_info=file_info,
+                    cache_control=cache_control,
+                    expires=expires,
+                    content_disposition=content_disposition,
+                    content_encoding=content_encoding,
+                    content_language=content_language,
+                )
                 return self.api.services.copy_manager.copy_file(
                     copy_source,
                     new_file_name,
@@ -1185,7 +1418,6 @@ class Bucket(metaclass=B2TraceMeta):
                     source_encryption=source_encryption,
                     file_retention=file_retention,
                     legal_hold=legal_hold,
-                    cache_control=cache_control,
                 ).result()
             except CopySourceTooBig as e:
                 copy_source.length = e.size
@@ -1207,15 +1439,17 @@ class Bucket(metaclass=B2TraceMeta):
             max_part_size=max_part_size,
         )
 
-    def delete_file_version(self, file_id, file_name):
+    def delete_file_version(self, file_id: str, file_name: str, bypass_governance: bool = False):
         """
         Delete a file version.
 
-        :param str file_id: a file ID
-        :param str file_name: a file name
+        :param file_id: a file ID
+        :param file_name: a file name
+        :param bypass_governance: Must be set to true if deleting a file version protected by Object Lock governance
+                                  mode retention settings (unless its retention period expired)
         """
         # filename argument is not first, because one day it may become optional
-        return self.api.delete_file_version(file_id, file_name)
+        return self.api.delete_file_version(file_id, file_name, bypass_governance)
 
     @disable_trace
     def as_dict(self):
