@@ -26,6 +26,7 @@ from b2sdk.replication.setting import ReplicationConfiguration
 from .b2http import ResponseContextManager
 from .encryption.setting import EncryptionMode, EncryptionSetting
 from .exception import (
+    AccessDenied,
     BadJson,
     BadRequest,
     BadUploadUrl,
@@ -51,6 +52,7 @@ from .file_lock import (
     BucketRetentionSetting,
     FileRetentionSetting,
     LegalHold,
+    RetentionMode,
 )
 from .file_version import UNVERIFIED_CHECKSUM_PREFIX
 from .raw_api import ALL_CAPABILITIES, AbstractRawApi, LifecycleRule, MetadataDirectiveMode
@@ -176,7 +178,6 @@ class FileSimulator:
         file_retention: FileRetentionSetting | None = None,
         legal_hold: LegalHold = LegalHold.UNSET,
         replication_status: ReplicationStatus | None = None,
-        cache_control: str | None = None,
     ):
         if action == 'hide':
             assert server_side_encryption is None
@@ -201,7 +202,6 @@ class FileSimulator:
         self.file_retention = file_retention
         self.legal_hold = legal_hold if legal_hold is not None else LegalHold.UNSET
         self.replication_status = replication_status
-        self.cache_control = cache_control
 
         if action == 'start':
             self.parts = []
@@ -297,7 +297,6 @@ class FileSimulator:
             action=self.action,
             uploadTimestamp=self.upload_timestamp,
             replicationStatus=self.replication_status and self.replication_status.value,
-            cacheControl=self.cache_control,
         )  # yapf: disable
         if self.server_side_encryption is not None:
             result['serverSideEncryption'
@@ -319,7 +318,6 @@ class FileSimulator:
             action=self.action,
             uploadTimestamp=self.upload_timestamp,
             replicationStatus=self.replication_status and self.replication_status.value,
-            cacheControl=self.cache_control,
         )  # yapf: disable
         if self.server_side_encryption is not None:
             result['serverSideEncryption'
@@ -344,7 +342,6 @@ class FileSimulator:
             fileInfo=self.file_info,
             uploadTimestamp=self.upload_timestamp,
             replicationStatus=self.replication_status and self.replication_status.value,
-            cacheControl=self.cache_control,
         )  # yapf: disable
         if self.server_side_encryption is not None:
             result['serverSideEncryption'
@@ -524,9 +521,8 @@ class BucketSimulator:
         # File IDs count down, so that the most recent will come first when they are sorted.
         self.file_id_counter = iter(range(self.FIRST_FILE_NUMBER, 0, -1))
         self.upload_timestamp_counter = iter(range(5000, 9999))
-        self.file_id_to_file = dict()
-        # It would be nice to use an OrderedDict for this, but 2.6 doesn't have it.
-        self.file_name_and_id_to_file = dict()
+        self.file_id_to_file: dict[str, FileSimulator] = dict()
+        self.file_name_and_id_to_file: dict[tuple[str, str], FileSimulator] = dict()
         if default_server_side_encryption is None:
             default_server_side_encryption = EncryptionSetting(mode=EncryptionMode.NONE)
         self.default_server_side_encryption = default_server_side_encryption
@@ -537,6 +533,12 @@ class BucketSimulator:
             assert self.replication.asReplicationSource is None or self.replication.asReplicationSource.rules
             assert self.replication.asReplicationDestination is None or self.replication.asReplicationDestination.sourceToDestinationKeyMapping
 
+    def get_file(self, file_id, file_name) -> FileSimulator:
+        try:
+            return self.file_name_and_id_to_file[(file_name, file_id)]
+        except KeyError:
+            raise FileNotPresent(file_id_or_name=file_id)
+
     def is_allowed_to_read_bucket_encryption_setting(self, account_auth_token):
         return self._check_capability(account_auth_token, 'readBucketEncryption')
 
@@ -612,9 +614,23 @@ class BucketSimulator:
             fileName=file_sim.name
         )  # yapf: disable
 
-    def delete_file_version(self, file_id, file_name):
+    def delete_file_version(
+        self, account_auth_token, file_id, file_name, bypass_governance: bool = False
+    ):
         key = (file_name, file_id)
-        file_sim = self.file_name_and_id_to_file[key]
+        file_sim = self.get_file(file_id, file_name)
+        if file_sim.file_retention:
+            if file_sim.file_retention.retain_until and file_sim.file_retention.retain_until > int(
+                time.time()
+            ):
+                if file_sim.file_retention.mode == RetentionMode.COMPLIANCE:
+                    raise AccessDenied()
+                elif file_sim.file_retention.mode == RetentionMode.GOVERNANCE:
+                    if not bypass_governance:
+                        raise AccessDenied()
+                    if not self._check_capability(account_auth_token, 'bypassGovernance'):
+                        raise AccessDenied()
+
         del self.file_name_and_id_to_file[key]
         del self.file_id_to_file[file_id]
         return dict(fileId=file_id, fileName=file_name, uploadTimestamp=file_sim.upload_timestamp)
@@ -753,7 +769,6 @@ class BucketSimulator:
         source_server_side_encryption: EncryptionSetting | None = None,
         file_retention: FileRetentionSetting | None = None,
         legal_hold: LegalHold | None = None,
-        cache_control: str | None = None,
     ):
         if metadata_directive is not None:
             assert metadata_directive in tuple(MetadataDirectiveMode), metadata_directive
@@ -796,7 +811,6 @@ class BucketSimulator:
             server_side_encryption=sse,
             file_retention=file_retention,
             legal_hold=legal_hold,
-            cache_control=cache_control,
         )  # yapf: disable
         destination_bucket.file_id_to_file[copy_file_sim.file_id] = copy_file_sim
         destination_bucket.file_name_and_id_to_file[copy_file_sim.sort_key()] = copy_file_sim
@@ -831,7 +845,6 @@ class BucketSimulator:
             server_side_encryption=sse,
             file_retention=file_retention,
             legal_hold=legal_hold,
-            cache_control=cache_control,
         )
 
     def list_file_names(
@@ -934,7 +947,6 @@ class BucketSimulator:
         file_retention: FileRetentionSetting | None = None,
         legal_hold: LegalHold | None = None,
         custom_upload_timestamp: int | None = None,
-        cache_control: str | None = None,
     ):
         file_id = self._next_file_id()
         sse = server_side_encryption or self.default_server_side_encryption
@@ -948,7 +960,7 @@ class BucketSimulator:
         file_sim = self.FILE_SIMULATOR_CLASS(
             self.account_id, self, file_id, 'start', file_name, content_type, 'none',
             file_info, None, upload_timestamp, server_side_encryption=sse,
-            file_retention=file_retention, legal_hold=legal_hold, cache_control=cache_control,
+            file_retention=file_retention, legal_hold=legal_hold,
         )  # yapf: disable
         self.file_id_to_file[file_id] = file_sim
         self.file_name_and_id_to_file[file_sim.sort_key()] = file_sim
@@ -1013,7 +1025,6 @@ class BucketSimulator:
         file_retention: FileRetentionSetting | None = None,
         legal_hold: LegalHold | None = None,
         custom_upload_timestamp: int | None = None,
-        cache_control: str | None = None,
     ):
         data_bytes = self._simulate_chunked_post(data_stream, content_length)
         assert len(data_bytes) == content_length
@@ -1052,7 +1063,6 @@ class BucketSimulator:
             server_side_encryption=encryption,
             file_retention=file_retention,
             legal_hold=legal_hold,
-            cache_control=cache_control,
         )
         self.file_id_to_file[file_id] = file_sim
         self.file_name_and_id_to_file[file_sim.sort_key()] = file_sim
@@ -1178,10 +1188,10 @@ class RawSimulator(AbstractRawApi):
         # Counter for generating account IDs an their matching master application keys.
         self.account_counter = 0
 
-        self.bucket_name_to_bucket = dict()
-        self.bucket_id_to_bucket = dict()
+        self.bucket_name_to_bucket: dict[str, BucketSimulator] = dict()
+        self.bucket_id_to_bucket: dict[str, BucketSimulator] = dict()
         self.bucket_id_counter = iter(range(100))
-        self.file_id_to_bucket_id = {}
+        self.file_id_to_bucket_id: dict[str, str] = {}
         self.all_application_keys = []
         self.app_key_counter = 0
         self.upload_errors = []
@@ -1352,11 +1362,15 @@ class RawSimulator(AbstractRawApi):
         self.all_application_keys.append(key_sim)
         return key_sim.as_created_key()
 
-    def delete_file_version(self, api_url, account_auth_token, file_id, file_name):
-        bucket_id = self.file_id_to_bucket_id[file_id]
+    def delete_file_version(
+        self, api_url, account_auth_token, file_id, file_name, bypass_governance: bool = False
+    ):
+        bucket_id = self.file_id_to_bucket_id.get(file_id)
+        if not bucket_id:
+            raise FileNotPresent(file_id_or_name=file_id)
         bucket = self._get_bucket_by_id(bucket_id)
         self._assert_account_auth(api_url, account_auth_token, bucket.account_id, 'deleteFiles')
-        return bucket.delete_file_version(file_id, file_name)
+        return bucket.delete_file_version(account_auth_token, file_id, file_name, bypass_governance)
 
     def update_file_retention(
         self,
@@ -1517,7 +1531,6 @@ class RawSimulator(AbstractRawApi):
         source_server_side_encryption=None,
         file_retention: FileRetentionSetting | None = None,
         legal_hold: LegalHold | None = None,
-        cache_control: str | None = None,
     ):
         bucket_id = self.file_id_to_bucket_id[source_file_id]
         bucket = self._get_bucket_by_id(bucket_id)
@@ -1543,7 +1556,6 @@ class RawSimulator(AbstractRawApi):
             source_server_side_encryption=source_server_side_encryption,
             file_retention=file_retention,
             legal_hold=legal_hold,
-            cache_control=cache_control,
         )
 
         return copy_file_sim.as_upload_result(account_auth_token)
@@ -1734,7 +1746,6 @@ class RawSimulator(AbstractRawApi):
         file_retention: FileRetentionSetting | None = None,
         legal_hold: LegalHold | None = None,
         custom_upload_timestamp: int | None = None,
-        cache_control: str | None = None,
     ):
         bucket = self._get_bucket_by_id(bucket_id)
         self._assert_account_auth(api_url, account_auth_token, bucket.account_id, 'writeFiles')
@@ -1747,7 +1758,6 @@ class RawSimulator(AbstractRawApi):
             file_retention,
             legal_hold,
             custom_upload_timestamp=custom_upload_timestamp,
-            cache_control=cache_control,
         )
         self.file_id_to_bucket_id[result['fileId']] = bucket_id
 
@@ -1797,7 +1807,6 @@ class RawSimulator(AbstractRawApi):
         file_retention: FileRetentionSetting | None,
         legal_hold: LegalHold | None,
         custom_upload_timestamp: int | None = None,
-        cache_control: str | None = None,
     ) -> dict:
 
         # fix to allow calculating headers on unknown key - only for simulation
@@ -1817,7 +1826,6 @@ class RawSimulator(AbstractRawApi):
             file_retention=file_retention,
             legal_hold=legal_hold,
             custom_upload_timestamp=custom_upload_timestamp,
-            cache_control=cache_control,
         )
 
     def upload_file(
@@ -1834,7 +1842,6 @@ class RawSimulator(AbstractRawApi):
         file_retention: FileRetentionSetting | None = None,
         legal_hold: LegalHold | None = None,
         custom_upload_timestamp: int | None = None,
-        cache_control: str | None = None,
     ):
         with ConcurrentUsedAuthTokenGuard(
             self.currently_used_auth_tokens[upload_auth_token], upload_auth_token
@@ -1866,7 +1873,6 @@ class RawSimulator(AbstractRawApi):
                 file_retention=file_retention,
                 legal_hold=legal_hold,
                 custom_upload_timestamp=custom_upload_timestamp,
-                cache_control=cache_control,
             )
 
             response = bucket.upload_file(
@@ -1882,7 +1888,6 @@ class RawSimulator(AbstractRawApi):
                 file_retention,
                 legal_hold,
                 custom_upload_timestamp,
-                cache_control,
             )
             file_id = response['fileId']
             self.file_id_to_bucket_id[file_id] = bucket_id
@@ -1932,7 +1937,7 @@ class RawSimulator(AbstractRawApi):
             if file_name is not None and not file_name.startswith(key_sim.name_prefix_or_none):
                 raise Unauthorized('', 'unauthorized')
 
-    def _get_bucket_by_id(self, bucket_id):
+    def _get_bucket_by_id(self, bucket_id) -> BucketSimulator:
         if bucket_id not in self.bucket_id_to_bucket:
             raise NonExistentBucket(bucket_id)
         return self.bucket_id_to_bucket[bucket_id]
