@@ -88,7 +88,6 @@ class Emerger(metaclass=B2TraceMetaAbstract):
         large_file_sha1: Sha1HexDigest | None = None,
         check_first_intent_for_sha1: bool = True,
         custom_upload_timestamp: int | None = None,
-        cache_control: str | None = None,
     ):
         planner = self.get_emerge_planner(
             min_part_size=min_part_size,
@@ -128,7 +127,6 @@ class Emerger(metaclass=B2TraceMetaAbstract):
             # Passing anything for small files does nothing.
             max_queue_size=max_queue_size,
             custom_upload_timestamp=custom_upload_timestamp,
-            cache_control=cache_control,
         )
 
     def emerge(
@@ -148,7 +146,6 @@ class Emerger(metaclass=B2TraceMetaAbstract):
         max_part_size: int | None = None,
         large_file_sha1: Sha1HexDigest | None = None,
         custom_upload_timestamp: int | None = None,
-        cache_control: str | None = None,
     ):
         """
         Create a new file (object in the cloud, really) from an iterable (list, tuple etc) of write intents.
@@ -172,7 +169,6 @@ class Emerger(metaclass=B2TraceMetaAbstract):
         :param max_part_size: upper limit of part size for the transfer planner, in bytes
         :param large_file_sha1: SHA1 for this file, if ``None`` and there's exactly one intent, it'll be taken from it
         :param custom_upload_timestamp: override object creation date, expressed as a number of milliseconds since epoch
-        :param cache_control: cache control header value
         """
         return self._emerge(
             EmergePlanner.get_emerge_plan,
@@ -191,7 +187,6 @@ class Emerger(metaclass=B2TraceMetaAbstract):
             max_part_size=max_part_size,
             large_file_sha1=large_file_sha1,
             custom_upload_timestamp=custom_upload_timestamp,
-            cache_control=cache_control,
         )
 
     def emerge_stream(
@@ -212,7 +207,6 @@ class Emerger(metaclass=B2TraceMetaAbstract):
         max_part_size: int | None = None,
         large_file_sha1: Sha1HexDigest | None = None,
         custom_upload_timestamp: int | None = None,
-        cache_control: str | None = None,
     ):
         """
         Create a new file (object in the cloud, really) from a stream of write intents.
@@ -237,7 +231,6 @@ class Emerger(metaclass=B2TraceMetaAbstract):
         :param max_part_size: upper limit of part size for the transfer planner, in bytes
         :param large_file_sha1: SHA1 for this file, if ``None`` and there's exactly one intent, it'll be taken from it
         :param custom_upload_timestamp: override object creation date, expressed as a number of milliseconds since epoch
-        :param cache_control: cache control header value
         """
         return self._emerge(
             EmergePlanner.get_streaming_emerge_plan,
@@ -257,7 +250,6 @@ class Emerger(metaclass=B2TraceMetaAbstract):
             max_part_size=max_part_size,
             large_file_sha1=large_file_sha1,
             custom_upload_timestamp=custom_upload_timestamp,
-            cache_control=cache_control,
         )
 
     def emerge_unbound(
@@ -278,7 +270,6 @@ class Emerger(metaclass=B2TraceMetaAbstract):
         max_part_size: int | None = None,
         large_file_sha1: Sha1HexDigest | None = None,
         custom_upload_timestamp: int | None = None,
-        cache_control: str | None = None,
     ):
         """
         Create a new file (object in the cloud, really) from an unbound stream of write intents.
@@ -303,7 +294,6 @@ class Emerger(metaclass=B2TraceMetaAbstract):
         :param max_part_size: upper limit of part size for the transfer planner, in bytes
         :param large_file_sha1: SHA1 for this file, if ``None`` it's left unset
         :param custom_upload_timestamp: override object creation date, expressed as a number of milliseconds since epoch
-        :param cache_control: cache control header value
         """
         return self._emerge(
             EmergePlanner.get_unbound_emerge_plan,
@@ -324,7 +314,6 @@ class Emerger(metaclass=B2TraceMetaAbstract):
             large_file_sha1=large_file_sha1,
             check_first_intent_for_sha1=False,
             custom_upload_timestamp=custom_upload_timestamp,
-            cache_control=cache_control,
         )
 
     def get_emerge_planner(
